summaryrefslogtreecommitdiffstats
path: root/korganizer/kodialogmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/kodialogmanager.cpp')
-rw-r--r--korganizer/kodialogmanager.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/korganizer/kodialogmanager.cpp b/korganizer/kodialogmanager.cpp
index 296bde57..9ceb1979 100644
--- a/korganizer/kodialogmanager.cpp
+++ b/korganizer/kodialogmanager.cpp
@@ -90,7 +90,7 @@ KODialogManager::KODialogManager( CalendarView *mainView ) :
mFilterEditDialog = 0;
mCategoryEditDialog = new KPIM::CategoryEditDialog( KOPrefs::instance(), mMainView );
// don't set any specific tqparent for the dialog, as its kept around and reused
// in different cases where it should have different parents
KWin::setMainWindow( mCategoryEditDialog, 0 );
connect( mainView, TQT_SIGNAL( categoriesChanged() ),
@@ -108,9 +108,9 @@ KODialogManager::~KODialogManager()
delete mFilterEditDialog;
}
-void KODialogManager::errorSaveIncidence( TQWidget *tqparent, Incidence *incidence )
+void KODialogManager::errorSaveIncidence( TQWidget *parent, Incidence *incidence )
{
- KMessageBox::sorry( tqparent, i18n("Unable to save %1 \"%2\".")
+ KMessageBox::sorry( parent, i18n("Unable to save %1 \"%2\".")
.tqarg( i18n( incidence->type() ) )
.tqarg( incidence->summary() ) );
}
@@ -90,7 +90,7 @@ KODialogManager::KODialogManager( CalendarView *mainView ) :
mFilterEditDialog = 0;
mCategoryEditDialog = new KPIM::CategoryEditDialog( KOPrefs::instance(), mMainView );
- // don't set any specific tqparent for the dialog, as its kept around and reused
+ // don't set any specific parent for the dialog, as its kept around and reused
// in different cases where it should have different parents
KWin::setMainWindow( mCategoryEditDialog, 0 );